@@ -11,11 +11,8 @@ OD_CALIBRATION_DATA_FILENAME = "OD_calibration_data.csv"
 PUMP_CALIBRATION_DATA_FILENAME = "PUMP_calibration_data.csv"
 OD_DATA_FILENAME = "OD_data.csv"
 
-FRONTSIGNAL_RAW_FILENAME = "current_front.csv"
-SIDESIGNAL_RAW_FILENAME = "current_side.csv"
-
 class Experiment:
-    def __init__(self, name="NewExperiment", connect=True, device_serial="auto"):
+    def __init__(self, name="NewExperiment", connect=True, device_serial="auto",fit_calibration_functions=True):
         """
         :param name: Experiment name with no spaces, e.g. starting date
         :param device_serial: board serial number or "auto" to auto-connect
@@ -31,11 +28,8 @@ class Experiment:
             print("Not connected to device")
         self.Valves = Valves(self)
         self.Photodiodes = Photodiodes(self)
-        self.OD_measurement = ODmeasurement(self)
+        self.OD_measurement = ODmeasurement(self, fit_calibration_functions=fit_calibration_functions)
         self.Pumps = Pumps(self)
-
-        self.frontsignal_rawfile = os.path.join(self.name,FRONTSIGNAL_RAW_FILENAME)
-        self.sidesignal_rawfile = os.path.join(self.name,SIDESIGNAL_RAW_FILENAME)
     def mix(self, speed=70, period=3000):
         assert 30 <= speed <= 100 or speed == 0
         if speed > 0:
