@@ -1,20 +1,36 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from peacedeath import pm
+import os
+import time
 
+CURRENT_DATA_FILENAME = "current_data.csv"
 
 class Photodiodes:
     def __init__(self, pe):
         self.pe = pe
         self.dev = pe.dev
+        self.current_file = os.path.join(self.pe.name, CURRENT_DATA_FILENAME)
+
 
     def measure_current(self, tube, cycles=10, n_measurements=40, laserOnDelay=10, laserOffDelay=10,
-                        filter_errors=True, verbose=False):
-        current_front, current_side = _measure_current(dev=self.dev, tube=tube, cycles=cycles,
+                        filter_errors=True, verbose=False, log = True):
+        IFS, ISS, IFSoff, ISSoff = _measure_current(dev=self.dev, tube=tube, cycles=cycles,
                                                        n_measurements=n_measurements, laserOnDelay=laserOnDelay,
                                                        laserOffDelay=laserOffDelay, filter_errors=filter_errors,
                                                        verbose=verbose)
-        return current_front, current_side
+        if log:
+            self.log_current(IFS, ISS, IFSoff, ISSoff)
+        return IFS, ISS, IFSoff, ISSoff
+
+    def log_current(self, IFS, ISS, IFSoff, ISSoff):
+        if not os.path.exists(self.current_file):
+            with open(self.current_file, "w+") as f:
+                f.write("time, front, side, front_off, side_off\n")
+        current_time=time.ctime()
+        with open(self.current_file,"a") as f:
+            f.write("{time}, {IFS:.2f}, {ISS:.2f}, {IFSoff:.2f}, {ISSoff:.2f}\n".format(time=current_time, IFS=IFS,
+                                                    ISS=ISS, IFSoff=IFSoff, ISSoff=ISSoff))
 
 
 def get_4_signals(dev, tube, resistor1=100, resistor2=10, laserOnDelay=10, laserOffDelay=1,
@@ -35,7 +51,7 @@ def get_4_signals(dev, tube, resistor1=100, resistor2=10, laserOnDelay=10, laser
                                                  resistor1=resistor1,
                                                  resistor2=resistor2))
 
-    return s4.onFS, s4.onSS, s4.offFS, s4.offFS
+    return s4.onFS, s4.onSS, s4.offFS, s4.offSS
 
 
 def get_r2list(dev, tube=4, n=20):
@@ -70,7 +86,7 @@ def get_r2list(dev, tube=4, n=20):
     return r2list
 
 
-def measure_voltage(dev, tube, cycles=10, n_measurements=40, laserOnDelay=10, laserOffDelay=10):
+def measure_voltage(dev, tube, cycles=10, n_measurements=40, laserOnDelay=10, laserOffDelay=10,verbose=False):
     rlist = get_r2list(dev, tube, n=n_measurements)
     r1 = 200
     V = []
@@ -81,22 +97,26 @@ def measure_voltage(dev, tube, cycles=10, n_measurements=40, laserOnDelay=10, la
         cycles = int(cycles)
         if cycles > 100:
             cycles = 99
-        print("Cycles=", cycles)
+        if verbose:
+            print("Cycles=", cycles)
     for r1_binary, r2_binary in zip(np.linspace(1, 255, len(rlist)).astype(int), rlist):
         #         print(r1_binary,r2_binary)
         u = get_4_signals(dev=dev, tube=tube, resistor1=r1_binary, resistor2=r2_binary, laserOnDelay=laserOnDelay,
                              laserOffDelay=laserOffDelay, cycles=cycles, bias=0)
         u = [(3.3 / 4095) * i / (10 * cycles) for i in u]
         V += [u]
-        r2 = int(52 + r2_binary * 10000 / 256)
-        r1 = int(52 + r1_binary * 10000 / 256)
+        r2 = int(52 + r2_binary * 10000 / 256) # MCP42010 actual resistance
+        r1 = int(52 + r1_binary * 10000 / 256) # MCP42010 actual resistance
         Rfs += [r2]
         Rss += [r1]
-    Vfs = np.array(V)[:, 0]  # onFS
-    Vss = np.array(V)[:, 2]  # onFS
+    Vfs_on = np.array(V)[:, 0]  # onFS
+    Vss_on = np.array(V)[:, 1]  # onSS
+
+    Vfs_off = np.array(V)[:, 2]  # offFS
+    Vss_off = np.array(V)[:, 3]  # offSS
     Rfs = np.array(Rfs)
     Rss = np.array(Rss)
-    return Vfs, Rfs, Vss, Rss
+    return Vfs_on, Vfs_off, Rfs, Vss_on, Vss_off, Rss
 
 
 def calculate_current(V, R, filter_errors=True):
@@ -134,19 +154,26 @@ def calculate_current(V, R, filter_errors=True):
 
 def _measure_current(dev, tube, cycles=10, n_measurements=40, laserOnDelay=10, laserOffDelay=10, filter_errors=True,
                      verbose=False):
-    Vfs, Rfs, Vss, Rss = measure_voltage(dev=dev, tube=tube, cycles=cycles, n_measurements=n_measurements,
-                                         laserOnDelay=laserOnDelay, laserOffDelay=laserOffDelay)
-    IFS, _, R2FS = calculate_current(Vfs, Rfs, filter_errors=filter_errors)
-    ISS, _, R2SS = calculate_current(Vss, Rss, filter_errors=filter_errors)
+    Vfs_on, Vfs_off, Rfs, Vss_on, Vss_off, Rss = measure_voltage(dev=dev, tube=tube, cycles=cycles, n_measurements=n_measurements,
+                                         laserOnDelay=laserOnDelay, laserOffDelay=laserOffDelay, verbose=verbose)
+
+
+    IFS, _, R2FS = calculate_current(Vfs_on, Rfs, filter_errors=filter_errors)
+    IFSoff, _, R2FS = calculate_current(Vfs_off, Rfs, filter_errors=filter_errors)
+
+    ISS, _, R1SS = calculate_current(Vss_on, Rss, filter_errors=filter_errors)
+    ISSoff, _, R1SS = calculate_current(Vss_off, Rss, filter_errors=filter_errors)
 
     if verbose:
         fig, axs = plt.subplots(2, 1)
-        axs[0].plot(Rfs, Vfs, "ro--", label="Front Detector, I=%.1f μA" % IFS)
+        axs[0].plot(Rfs, Vfs_on, "ro--", label="Front Detector laser on, I=%.1f μA" % IFS)
+        axs[0].plot(Rfs, Vfs_off, "ro--", label="Front Detector laser off, I=%.1f μA" % IFSoff, alpha=0.3)
         axs[0].legend()
-        axs[1].plot(Rss, Vss, "bo--", label="Side Detector, I=%.1f μA" % ISS)
+        axs[1].plot(Rss, Vss_on, "bo--", label="Side Detector laser on, I=%.1f μA" % ISS)
+        axs[1].plot(Rss, Vss_off, "bo--", label="Side Detector laser off, I=%.1f μA" % ISSoff,alpha=0.3)
         axs[1].legend()
         plt.xlabel("Resistance (Ohms)")
         axs[1].set_ylabel("Voltage")
         axs[0].set_ylabel("Voltage")
         plt.show()
-    return IFS, ISS
+    return IFS, ISS, IFSoff, ISSoff
